@@ -14,6 +14,7 @@ use fields (
 
 use Net::IMP qw(:DEFAULT :log);
 use Net::IMP::Debug;
+use App::HTTP_Proxy_IMP::IMP ':dtypes';
 
 sub USED_RTYPES { return (
     IMP_REPLACE, # remove Cookie/Authorization header
@@ -22,6 +23,17 @@ sub USED_RTYPES { return (
     IMP_PASS,
 )}
 
+sub supported_dtypes { return (
+    # claim to support all types needed for HTTP
+    # we only need to make sure, that we keep type boundaries when modifying
+    # e.g. don't make header + body data out of header etc or issue replace
+    # for part of header only
+    IMP_DATA_MESSAGE_HDR,
+    IMP_DATA_CHUNK_HDR,
+    IMP_DATA_CHUNK_TRAILER,
+    IMP_DATA_STREAM,
+)}
+
 sub new_analyzer {
     my ($class,%args) = @_;
     my $self = $class->SUPER::new_analyzer(%args);
